@@ -212,8 +212,7 @@ fn flatpak(target_dir: PathBuf, arguments: Flatpak) {
         ) {
             eprintln!(
                 "[gra] Could not move target/gra-gen/data/{0}.yml to target/{0}.yml: {1}",
-                &project_descriptor.app.id,
-                e.to_string()
+                &project_descriptor.app.id, e
             );
             return;
         }
@@ -232,15 +231,12 @@ fn flatpak(target_dir: PathBuf, arguments: Flatpak) {
             .spawn()
         {
             Err(e) => {
-                eprintln!(
-                    "[gra] tar flatpak-temp resulted in error: {}",
-                    e.to_string()
-                );
+                eprintln!("[gra] tar flatpak-temp resulted in error: {}", e);
                 return;
             }
             Ok(mut c) => {
                 if let Err(e) = c.wait() {
-                    eprintln!("[gra] tar command failed: {}", e.to_string());
+                    eprintln!("[gra] tar command failed: {}", e);
                     return;
                 }
             }
@@ -251,15 +247,14 @@ fn flatpak(target_dir: PathBuf, arguments: Flatpak) {
         if let Err(e) = sha {
             eprintln!(
                 "[gra] sha256sum for {:?} resulted in error: {}",
-                &tar_file,
-                e.to_string()
+                &tar_file, e
             );
             return;
         }
 
         let sha = String::from_utf8_lossy(&sha.unwrap().stdout)
             .to_string()
-            .split_once(" ")
+            .split_once(' ')
             .unwrap()
             .0
             .trim()
